@@ -17,8 +17,9 @@ from .ttgrappa import ttgrappa
 from .pars import pars
 from .radialgrappaop import radialgrappaop
 from .grog import grog
-from .grog_powers import grog_powers # pylint: disable=E0611
-from .grog_gridding import grog_gridding # pylint: disable=E0611
 # from .kspa import kspa
 from .nlgrappa import nlgrappa
+from .nlgrappa_matlab import nlgrappa_matlab
 from .gfactor import gfactor, gfactor_single_coil_R2
+from .sense1d import sense1d
+from .cgsense import cgsense
